a list containing var with variance estimates as well as
trt_* and lsm_* entries. See rbmi_ancova() for full details.
Arguments
data
A data.frame containing the data to be used in the model.
outcome
string, the name of the outcome variable in data.
group
string, the name of the group variable in data.
covariates
character vector containing the name of any additional covariates
to be included in the model as well as any interaction terms.
weights
Character, either "counterfactual" (default), "equal",
"proportional_em" or "proportional".
Specifies the weighting strategy to be used when calculating the lsmeans.
See the weighting section for more details.
Details
group must be a factor variable with only 2 levels.