- df
(data.frame)
data set containing all analysis variables.
- labelstr
(character)
label of the level of the parent split currently being summarized
(must be present as second argument in Content Row Functions). See rtables::summarize_row_groups()
for more information.
- .var
(string)
single variable name that is passed by rtables when requested
by a statistics function.
- val
(character or NULL)
When NULL, all levels of the incoming variable (variable used in the analyze call)
will be considered.
When a single string, only that current level/value of the incoming variable
will be considered.
When multiple levels, only those levels/values of the incoming variable
will be considered.
When no values are observed (eg zero row input df),
a row with row-label No data reported will be included in the table.
- subcol_split
(string)
text to search colid to determine whether further subsetting
should be performed.
- subcol_var
(string)
name of variable containing to be searched for the text
identified in subcol_val argument.
- subcol_val
(string)
value to use to perform further data sub-setting.
- .df_row
(data.frame)
data frame across all of the columns for the given row split.
- .spl_context
(data.frame)
gives information about ancestor split states
that is passed by rtables.
- .N_col
(integer)
column-wise N (column count) for the full column being analyzed that is typically
passed by rtables.
- id
(string)
subject variable name.
- denom
(string)
One of
N_col Column count,
n_df Number of patients (based upon the main input dataframe df),
n_altdf Number of patients from the secondary dataframe (.alt_df_full),
Note that argument denom_by will perform a row-split on the .alt_df_full dataframe.
It is a requirement that variables specified in denom_by are part of the row split specifications.
n_rowdf Number of patients from the current row-level dataframe
(.row_df from the rtables splitting machinery).
n_parentdf Number of patients from a higher row-level split than the current split.
This higher row-level split is specified in the argument denom_by.
- label
(string)
When val has length 1,
the row label to be shown on the output can be specified using this argument.
When val is a character vector, the label_map argument can be specified
to control the row-labels.
- label_fstr
(string)
a sprintf style format string.
It can contain up to one "%s", which takes the current split value and
generates the row/column label.
It will be combined with the labelstr argument,
when utilizing this function as
a cfun in a summarize_row_groups call.
It is recommended not to utilize this argument for other purposes.
The label argument could be used instead (if val is a single string)
- label_map
(tibble)
A mapping tibble to translate levels from the incoming variable into
a different row label to be presented on the table.
- .alt_df_full
(dataframe)
Denominator dataset
for fraction and relative risk calculations.
this argument gets populated by the rtables
split machinery (see rtables::additional_fun_params).
- denom_by
(character)
Variables from row-split
to be used in the denominator derivation.
This controls both denom = "n_parentdf" and denom = "n_altdf".
When denom = "n_altdf", the denominator is derived from .alt_df_full
in combination with denom_by argument
- .stats
(character)
statistics to select for the table.
- .formats
(named 'character' or 'list')
formats for the statistics.
- .labels_n
(named character)
String to control row labels for the 'n'-statistics.
Only useful when more than one 'n'-statistic is requested (rare situations only).
- .indent_mods
(named integer)
indent modifiers for the labels. Defaults to 0, which corresponds to the
unmodified default behavior. Can be negative.
- na_str
(string)
string used to replace all NA or empty values in the output.